@@ -55,6 +55,8 @@
 #include "Tools.h"
  
 bool MvQFileBrowser::quitStarted_=false;
+bool MvQFileBrowser::logoutStarted_=false;
+
 QList<MvQFileBrowser*> MvQFileBrowser::browsers_;
 
 MvQFileBrowser::MvQFileBrowser(QStringList relPathLst,QWidget *parent) : 
@@ -210,6 +212,9 @@ MvQFileBrowser::MvQFileBrowser(QStringList relPathLst,QWidget *parent) :
 	
 	if(relPathLst.count() > 0)
 	  	folderPanel_->resetWidgets(relPathLst);
+    
+	connect(qApp,SIGNAL(commitDataRequest(QSessionManager&)),
+			this,SLOT(slotCommitDataRequest(QSessionManager&)),Qt::DirectConnection);
 }
 
 MvQFileBrowser::~MvQFileBrowser()
@@ -233,7 +238,9 @@ void MvQFileBrowser::showIt()
 
 void MvQFileBrowser::closeEvent(QCloseEvent* event)
 {
-  	if(MvQFileBrowser::aboutToClose(this))
+	qDebug() << "closeEvent";
+    
+    if(MvQFileBrowser::aboutToClose(this))
 	{	
 		browsers_.removeOne(this);
 		saveFolderInfo();		
@@ -251,6 +258,16 @@ void MvQFileBrowser::slotQuit()
 	 MvQFileBrowser::aboutToQuit(this);  
 }  
 
+
+//This slot is called when the window mangager quits to ask the app to
+//close in a correct way. We set the logoutStarted_ flag to indicate that 
+//this happened. 
+void MvQFileBrowser::slotCommitDataRequest(QSessionManager& manager)
+{
+	qDebug() << "commit";    
+	logoutStarted_=true;
+}
+
 //==============================================================
 //
 //  Set up actions
@@ -1490,7 +1507,12 @@ bool MvQFileBrowser::aboutToClose(MvQFileBrowser* browser)
 		  	int tabCnt=browser->folderPanel_->count();
 			if(tabCnt > 1)
 			{
-		  		if(QMessageBox::question(0,tr("Confirm close"),tr("You are about to close <b>") + QString::number(tabCnt) + tr("</b> tabs. Are you sure you want to continue?"),
+                if(logoutStarted_)
+                {
+                    return true;
+                }    
+                
+                if(QMessageBox::question(0,tr("Confirm close"),tr("You are about to close <b>") + QString::number(tabCnt) + tr("</b> tabs. Are you sure you want to continue?"),
 			    	      QMessageBox::Yes | QMessageBox::Cancel,QMessageBox::Cancel) == QMessageBox::Cancel)
 				{		
 					return false;
@@ -1503,11 +1525,13 @@ bool MvQFileBrowser::aboutToClose(MvQFileBrowser* browser)
 		}	
 		return true;
 	}	
+	
+	return true;
 }	
 
 bool MvQFileBrowser::aboutToQuit(MvQFileBrowser* topBrowser)
 {
-  	if(QMessageBox::question(0,tr("Confirm quit"),tr("Do you want to quit Metview?"),
+	if(logoutStarted_ || QMessageBox::question(0,tr("Confirm quit"),tr("Do you want to quit Metview?"),
 			     QMessageBox::Yes | QMessageBox::Cancel,QMessageBox::Cancel) == QMessageBox::Yes)
 	{
 		quitStarted_=true;
@@ -1521,8 +1545,13 @@ bool MvQFileBrowser::aboutToQuit(MvQFileBrowser* topBrowser)
 		//Save browser settings
 		MvQFileBrowser::save(topBrowser);		
 		
+        if(logoutStarted_)
+            return true;
+        
 		//Exit metview
 		QApplication::quit();
+        
+        return true;
 	}
 	
 	return false;
