@@ -148,10 +148,8 @@ MvRequest HovToolkit::CreateOutputRequest()
    // Create netCDF output request
    MvRequest out1("NETCDF_XY_MATRIX");
    out1("NETCDF_PLOT_TYPE") = "XY_MATRIX";
-   string xAxisType, yAxisType;
+   out1("NETCDF_DATA") = req;
    const char* secondCoordName = GetSecondCoordName();
-   MvRequest horAxisReq, vertAxisReq;
-   bool latVertAxis = false;    // indicates if vertical axis is latitude
    if ( verticalAxis_ == HOV_TIME )  // TIME is vertical axis
    {
       out1("NETCDF_Y_VARIABLE") = HOV_VARTIME.c_str();;
@@ -160,19 +158,7 @@ MvRequest HovToolkit::CreateOutputRequest()
       {
          out1("NETCDF_X_AUXILIARY_VARIABLE") = GetSecondAuxiliaryCoordName();
          out1("NETCDF_X_GEOLINE_CONVENTION") = (const char*)GeolineConvention().c_str();
-         xAxisType = "geoline";
       }
-      else
-      {
-         if ( string(secondCoordName) == HOV_VARLAT || string(secondCoordName) == HOV_VARLON )
-         {
-            horAxisReq.setVerb("MAXIS");
-            horAxisReq("AXIS_ORIENTATION") = "HORIZONTAL";
-            horAxisReq("AXIS_TICK_LABEL_TYPE") = (secondCoordName == HOV_VARLAT) ? "Latitude" : "Longitude";
-         }
-         xAxisType = "regular";
-      }
-      yAxisType = "date";
    }
    else  // TIME is horizontal axis
    {
@@ -182,74 +168,39 @@ MvRequest HovToolkit::CreateOutputRequest()
       {
          out1("NETCDF_Y_AUXILIARY_VARIABLE") = GetSecondAuxiliaryCoordName();
          out1("NETCDF_Y_GEOLINE_CONVENTION") = (const char*)GeolineConvention().c_str();
-         yAxisType = "geoline";
       }
-      else
-      {
-         if ( secondCoordName == HOV_VARLAT || secondCoordName == HOV_VARLON )
-         {
-            vertAxisReq.setVerb("MAXIS");
-            vertAxisReq("AXIS_ORIENTATION") = "VERTICAL";
-            vertAxisReq("AXIS_TICK_LABEL_TYPE") = (secondCoordName == HOV_VARLAT) ? "Latitude" : "Longitude";
-         }
-         latVertAxis = (secondCoordName == HOV_VARLAT) ? true : false;
-         yAxisType = "regular";
-      }
-
-      xAxisType = "date";
    }
 
    out1("NETCDF_VALUE_VARIABLE") = getNetcdfVarname(par->ParamName()).c_str();
    out1("NETCDF_MISSING_ATTRIBUTE") = "_FillValue";
    out1("_VERB") = "NETCDF_XY_MATRIX";
 
-   // Create customised CARTESIANVIEW request.
-   // This is only needed if a HovData visualisation action was requested.
-   // If a dropped (data or HovData) action was requested, the View is taken
-   // from uPlot. In this implementation, the view request will be always
-   // sent because: a) it is clean; b) does not cause problem.
-   MvRequest viewReq("CARTESIANVIEW");
-   viewReq("X_AUTOMATIC") = "on";
-   viewReq("X_AXIS_TYPE") = xAxisType.c_str();
-   viewReq("Y_AUTOMATIC") = "on";
-   viewReq("Y_AXIS_TYPE") = yAxisType.c_str();
+   // Add information to help the Macro Converter to translate
+   // the output request to a Macro code
+   out1("_ORIGINAL_REQUEST") = this->buildMacroConverterRequest();
 
-   // If Y_AUTOMATIC is ON and AXIS_TICK_LABEL_TYPE is LATITUDE then
-   // reverte the axis values because Hovmoeller computes values from
-   // North to South and Magics plots them from bottom to top by default
-   if ( strcmp(viewReq("Y_AUTOMATIC"), "on") == 0 && latVertAxis )
-      viewReq("Y_AUTOMATIC_REVERSE") = "on";
-
-   if ( horAxisReq )
-      viewReq("HORIZONTAL_AXIS") = horAxisReq;
-
-   if ( vertAxisReq )
-      viewReq("VERTICAL_AXIS") = vertAxisReq;
+   // Create the View request taking values from the input application
+   MvRequest viewReq = CreateViewRequest();
 
    // Save min/max date. This info is important if the dates in the
    // original View are 'automatic'.
-   string xy = (yAxisType == "date") ? "Y_" : "X_";
    MvDate dd(dateMinD_);
-   string str = xy + "DATE_MIN";
-   viewReq(str.c_str()) = dd.magicsDate().c_str();
+   viewReq("DATE_MIN") = dd.magicsDate().c_str();
    dd = dateMaxD_;
-   str = xy + "DATE_MAX";
-   viewReq(str.c_str()) = dd.magicsDate().c_str();
+   viewReq("DATE_MAX") = dd.magicsDate().c_str();
 
    // If action is not visualisation related then return the netcdf data.
    // Also, add the visualisation and original requests as hidden parameters.
    // These may be used later to help the visualisation of the netcdf data.
-   MvRequest hovViewReq = CreateViewRequest();
-   req("_VIEW") = "MHOVMOELLERVIEW";
-   req("_VIEW_REQUEST") = hovViewReq;
-   req("_VISUALISE") = out1;
-   req("_CARTESIANVIEW") = viewReq;
-   req("_ORIGINAL_REQUEST") = origReq_;
    if ( !IsVisualise() )
+   {
+      req("_VIEW") = "MHOVMOELLERVIEW";
+      req("_VIEW_REQUEST") = viewReq;
+      req("_VISUALISE") = out1;
       return req;
+   }
 
    // Final output request
-   out1("NETCDF_DATA") = req;
    MvRequest out = viewReq + out1;
 
    return out;
@@ -260,10 +211,9 @@ MvRequest HovToolkit::CreateOutputRequest( MvRequest& in )
    // Create NetCDF output request
    MvRequest data = in.getSubrequest("DATA");
    MvRequest out1 = data.getSubrequest("_VISUALISE");
-   MvRequest viewReq = data.getSubrequest("_CARTESIANVIEW");
+   MvRequest viewReq = data.getSubrequest("_VIEW_REQUEST");
    data.unsetParam("_VISUALISE");        // to avoid duplication of info
    data.unsetParam("_VIEW_REQUEST");     // to avoid duplication of info
-   data.unsetParam("_CARTESIANVIEW");    // to avoid duplication of info
    data.unsetParam("_ORIGINAL_REQUEST"); // to avoid duplication of info
    out1("NETCDF_DATA") = data;
 
@@ -1057,3 +1007,23 @@ bool HovToolkit::ExpandGetTimeInfo()
 
    return true;
 }
+
+MvRequest HovToolkit::buildMacroConverterRequest()
+{
+   const char* caux = origReq_.getVerb();
+   MvRequest oreq( caux );
+   oreq("_MACRO_DECODE_TAG") = 1;  // extra info for the Macro Converter
+   oreq("_CLASS") = (const char*)origReq_("_CLASS") ? (const char*)origReq_("_CLASS") : caux;
+   oreq("_VERB") = (const char*)origReq_("_VERB") ? (const char*)origReq_("_VERB") : caux;
+   if ( strcmp((const char*)oreq("_CLASS"),"RETRIEVE") == 0  ||
+        strcmp((const char*)oreq("_CLASS"),"GRIB") == 0 )
+   {
+      MvRequest retReq = origReq_("DATA");
+      if ( (const char*)retReq("_NAME") )
+         oreq("_NAME") = (const char*)retReq("_NAME");
+   }
+   else if ( (const char*)origReq_("_NAME") )
+      oreq("_NAME") = (const char*)origReq_("_NAME");
+
+   return oreq;
+}
