@@ -12,6 +12,10 @@
 #include <MvRequest.h>
 #include <MvVersionInfo.h>
 
+#if defined(METVIEW_ODB)
+    #include "odb_api/odbcapi.h"
+#endif
+
 
 #include "macro.h"
 #include "script.h"
@@ -795,6 +799,13 @@ Value MetviewVersionFunction::Execute(int arity,Value *arg)
 	emos_version = emosnum_(&konoff);
 	set_value(r, "emos_version", "%d", emos_version);
 
+
+#if defined(METVIEW_ODB)
+	const char *odbapi_version = odb_api_version();
+	set_value(r, "odb_api_version", "%s", odbapi_version);
+#endif
+
+
 	return Value(r);
 }
 
