@@ -1365,7 +1365,7 @@ void MvQWmsUiClient::slotReplyGetCap(QNetworkReply* reply)
 			capability_ = QString(ba);
 		
 			//Uncomment these lines to load a getCapabilities file from the disk
-			/*QFile file("/var/tmp/cgr/PERFORCE/metview_4/src/OgcClient/marc_dla.xml");
+			/*QFile file("/var/tmp/dummy-user/PERFORCE/metview_4/src/OgcClient/marc_dla.xml");
     			if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
          			return;
 
@@ -1511,7 +1511,7 @@ void MvQWmsUiClient::slotReplyPreview(QNetworkReply* reply)
 			QString eMsg(ba);
 		
 			log->error(eMsg.toStdString() + "\n");
-			emit legendLoaded(QString());
+            emit previewLoaded(QString());
 			emit statusMessage(tr("Load preview <font color=red>(FAILED)</font>"));
 		}
 		else
