@@ -941,9 +941,9 @@ MvRequest Xsect::createOutputRequest( MvRequest& in)
    // Create NetCDF output request
    MvRequest data = in.getSubrequest("DATA");
    MvRequest out1 = data.getSubrequest("_VISUALISE");
-   MvRequest viewReq = data.getSubrequest("_CARTESIANVIEW");
+   MvRequest viewReq = data.getSubrequest("_VIEW_REQUEST");
    data.unsetParam("_VISUALISE");        // to avoid duplication of info
-   data.unsetParam("_CARTESIANVIEW");    // to avoid duplication of info
+   data.unsetParam("_VIEW_REQUEST");    // to avoid duplication of info
    data.unsetParam("_ORIGINAL_REQUEST"); // to avoid duplication of info
    out1("NETCDF_DATA") = data;
 
@@ -1047,6 +1047,26 @@ MvNcVar* Xsect::getNetcdfVariableLevel( MvNetCDF& cdf, const string& varname, Ap
    return ncv;
 }
 
+MvRequest Xsect::buildMacroConverterRequest()
+{
+   const char* caux = origReq_.getVerb();
+   MvRequest oreq( caux );
+   oreq("_MACRO_DECODE_TAG") = 1;  // extra info for the Macro Converter
+   oreq("_CLASS") = (const char*)origReq_("_CLASS") ? (const char*)origReq_("_CLASS") : caux;
+   oreq("_VERB") = (const char*)origReq_("_VERB") ? (const char*)origReq_("_VERB") : caux;
+   if ( strcmp((const char*)oreq("_CLASS"),"RETRIEVE") == 0 ||
+        strcmp((const char*)oreq("_CLASS"),"GRIB") == 0 )
+   {
+      MvRequest retReq = origReq_("DATA");
+      if ( (const char*)retReq("_NAME") )
+         oreq("_NAME") = (const char*)retReq("_NAME");
+   }
+   else if ( (const char*)origReq_("_NAME") )
+      oreq("_NAME") = (const char*)origReq_("_NAME");
+
+   return oreq;
+}
+
 //------------------------------------------------------------------------------
 
 int main(int argc,char **argv)
