@@ -1591,13 +1591,15 @@ long _readany(FILE *f, char *b, long *l)
 {
 	size_t len = *l;
 	long e =  wmo_read_any_from_file(f,(unsigned char*)b,&len);
-	*l = len;
 
-	if(e && e != GRIB_END_OF_FILE) 
-		marslog(LOG_EROR|LOG_PERR,"wmo_read_any_from_file: error %d (%s) l=%ld, len=%ld",e,
-			grib_get_error_message(e),len);
+    if(e && e != GRIB_END_OF_FILE) {
+        marslog(LOG_EROR|LOG_PERR,"wmo_read_any_from_file: error %d (%s) l=%ld, len=%ld", e,
+        grib_get_error_message(e), l, len);
+    }
 
-	return e;
+    *l = len;
+
+    return e;
 }
 
 long _readgrib(FILE *f, char *b, long *l)
