@@ -9,6 +9,7 @@
 
 #include <Metview.h>
 #include <MvPath.hpp>
+#include <MvScanFileType.h>
 
 MvRequest::MvRequest(const char *verb)
 {
@@ -868,11 +869,11 @@ void MvRequest :: update_value(request *r,const char *parname,const char *valnam
 
 	if(append)
 	{
-		value *a = p->values,*b= NULL,*c=NULL;
+		value *a = p->values,*b= NULL;
 		while(a)
 		{
 			b = a;
-			c = b;
+//			c = b;
 			a = a->next;
 		}
 		v = new_value(strcache(valname));
@@ -939,8 +940,8 @@ bool MvRequest::getPath(const char* par,string &resPath,bool canBeEmpty,string &
 			if(callerIcon)
 			{
 	  			string callerDir(callerIcon);	  	
-		        	char *mvudir=getenv("METVIEW_USER_DIRECTORY");
-		        	if(mvudir)  
+                char *mvudir=getenv("METVIEW_USER_DIRECTORY");
+                if(mvudir)
 				{
 	  				callerDir=string(mvudir) + "/" + callerDir;
 				}	
@@ -1155,42 +1156,83 @@ void MvRequest::importSubObjects(string& path, request* obj)
       return;
 
    // Read the definition file
-   request* l = read_language_file(defFile);
-   if ( !l )
+   request* rdef = read_language_file(defFile);
+   if ( !rdef )
       return;
 
-   // Skip auxiliary requests
-   while(l && (l->name != this->getVerb()))
-      l = l->next;
-
-   // Check each parameter to find out if it needs to be expanded
-   parameter* p = l->params;
-   MvRequest reqAux;
-   while (p)
+   // This request may be structured as a set of requests.
+   // Loop each request and expand all parameters that are subrequests.
+   this->rewind();
+   while (CurrentRequest)
    {
-      // Search for parameters that have an icon interface
-      const char *cicon = get_value(p->interface,"interface",0);
-      if (cicon && (strcmp(cicon,"icon") == 0))
-      {
-         // Build all subrequests and add to this parameter
-         int i = 0;
-         const char *q;
-         while ( (q = get_value(CurrentRequest,p->name,i++)) )
-         {            
-            // Build subrequest
-            string fullPath = path + "/" + q;;
-            reqAux.read(fullPath.c_str(),true);
+      // Find the correspondent definition request
+      request* rl = rdef;
+      while(rl && (rl->name != this->getVerb()))
+         rl = rl->next;
 
-            // Add subrequest to this parameter
-            if ( i == 1 )  // clean parameter values once
-               this->unsetParam(p->name);
-            
-            this->addValue(p->name,reqAux);
+      // Skip this request if there is no related definition request
+      if ( !rl )
+         continue;
+
+      // Check each parameter to find out if it needs to be expanded
+      parameter* p = rl->params;
+      MvRequest reqAux;
+      while (p)
+      {
+         // Search for parameters that have an icon interface
+         const char *cicon = get_value(p->interface,"interface",0);
+         if (cicon && (strcmp(cicon,"icon") == 0))
+         {
+            // Build all subrequests and add to this parameter
+            const char* cclass = get_value(p->interface,"class",0);
+            const char *q;
+            for ( int i = 0; i < this->countValues(p->name); i++ )
+            {            
+               // Build subrequest
+               this->getValue(q,p->name,i);
+               string fullPath = (path[path.size()-1] == '/') ? path + q : path + "/" + q;
+               if ( !IsBinaryOrMissingFile(fullPath.c_str()) )
+               {
+                  // Read request from file and add parameter _CLASS.
+                  // Do not add parameter _NAME because this request
+                  // will be built by loading the contents of a file.
+                  // Adding parameter _NAME will make further routines to
+                  // read the file again.
+                  reqAux.read(fullPath.c_str(),true);
+                  reqAux("_CLASS") = reqAux.getVerb();
+               }
+               else
+               {
+                  // Build request manually
+                  reqAux.setVerb(cclass);
+
+                  // Add hidden parameters
+                  reqAux("_CLASS") = cclass;
+
+                  // Name without the Metview user directory path
+                  string user_dir = GetUserDirectory();
+                  std::size_t found = fullPath.find(user_dir);
+                  if (found != std::string::npos)
+                     reqAux("_NAME") = fullPath.substr(found+user_dir.size()).c_str();
+                  else
+                     reqAux("_NAME") = fullPath.c_str();
+               }
+
+               // Add subrequest to this parameter
+               if ( i == 0 )  // clean parameter values once
+                  this->unsetParam(p->name);
+
+               this->addValue(p->name,reqAux);
+            }
          }
+
+         p = p->next;
       }
 
-      p = p->next;
+      CurrentRequest = CurrentRequest->next;
    }
+
+   this->rewind();
 }
 
 request* MvRequest::findRequestObject()
@@ -1213,3 +1255,29 @@ request* MvRequest::findRequestObject()
 
    return NULL;
 }
+
+bool MvRequest::checkParameters( MvRequest& req, vector<string>& params )
+{
+   const char *par, *v1, *v2;
+   int i,j,cnt1,cnt2;
+
+   for (i = 0; i < (signed)params.size(); i++ )
+   {
+      par = params[i].c_str();
+      cnt1 = this->iterInit(par);
+      cnt2 = req.iterInit(par);
+      if ( cnt1 && (cnt1 == cnt2) )
+      {
+         for (j = 0; j < cnt1; j++)
+         {
+            this->iterGetNextValue( v1 );
+            req.iterGetNextValue( v2 );
+            if ( v1 != v2 )
+               return false;
+         }
+      }
+      
+   }
+
+   return true;
+}
