@@ -400,8 +400,25 @@ static const char *scan_file(const char *file)
 
    //-- Check for IFS fortran namelists
   
-  
-  
+
+
+  // if it's binary then it might actually be a GRIB file with some extra
+  // header bits at the start e.g. GTS). GRIB_API has functionality to
+  // bypass these, so if it can get a GRIB handle then it must be a GRIB file.
+  // This may not be the most efficient way to find out, but it's a last resort.
+
+  if( fileType == eBinaryFile ) 
+  {  
+      grib_handle *gh;
+      int ge;
+      gh = grib_handle_new_from_file(NULL, f.f_, &ge);
+      if (gh != NULL)
+      {
+        grib_handle_delete(gh);
+        return "GRIB";
+      }
+  }
+
   
   //We have to do this check at this point, after
   //FLEXTRA was checked! 
