@@ -15,7 +15,7 @@
 #include <string>
 using std::string;
 
-Cached MakeUserPath    ( const Cached& name );
+string MakeUserPath    ( const string& name );
 string MakeUserDefPath ( const char* name, bool absolutePath=true );
 string MakeUserPrefPath( const char* name );
 string MakeSystemEtcPath  ( const string& name );
