@@ -8,6 +8,7 @@
  ***************************** LICENSE END *************************************/
 
 #include "MagPlusBatchService.h"
+#include "PlotMod.h"
 
 void
 MagPlusBatchService::CallMagPlus ( MvRequest& in )
@@ -17,7 +18,16 @@ MagPlusBatchService::CallMagPlus ( MvRequest& in )
 
     MvMagRequest request(in);
 
-	magplus_->execute(request);
+    try
+    {
+	    magplus_->execute(request);
+    }
+    catch (exception e)
+    {
+        std::string errorMsg("Could not produce plot: ");
+        errorMsg += e.what();
+        PlotMod::Instance().MetviewError ("errorMsg","Error");
+    }
 	//thread_.render(in,magplus_);
 
 	// the Magics log messages are not broadcast until the next log event - therefore, the
